package com.ruoyi.web.controller.system;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DataUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.FcryDTO;
import com.ruoyi.system.domain.Fkqk;
import com.ruoyi.system.mapper.SysUserMapper;
import com.ruoyi.system.service.impl.FkqkServiceImpl;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Fcry;
import com.ruoyi.system.service.IFcryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 方舱人员Controller
 *
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/fcry")
public class FcryController extends BaseController
{
    @Autowired
    private IFcryService fcryService;
    @Autowired
    private FkqkServiceImpl fkqkService;
    @Autowired
    private SysUserMapper sysUserMapper;

    /**
     * 查询方舱人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Fcry fcry)
    {
        String userType = sysUserMapper.selectUserTypeById(SecurityUtils.getUserId());
        fcry.setUserType(userType);
        if ("2".equals(userType))
            fcry.setValue(DataUtils.getKey(null, String.valueOf(SecurityUtils.getUserId()),null,null,null));
        else if ("3".equals(userType))
            fcry.setValue(DataUtils.getKey(null,null, String.valueOf(SecurityUtils.getUserId()),null,null));
        startPage();
        List<Fcry> list = fcryService.selectFcryList(fcry);
        return getDataTable(list);
    }

    /**
     * 导出方舱人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:export')")
    @Log(title = "方舱人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Fcry fcry)
    {
        String userType = sysUserMapper.selectUserTypeById(SecurityUtils.getUserId());
        fcry.setUserType(userType);
        if ("2".equals(userType))
            fcry.setValue(DataUtils.getKey(null, String.valueOf(SecurityUtils.getUserId()),null,null,null));
        else if ("3".equals(userType))
            fcry.setValue(DataUtils.getKey(null,null, String.valueOf(SecurityUtils.getUserId()),null,null));
        List<Fcry> list = fcryService.selectFcryListExport(fcry);
        ExcelUtil<Fcry> util = new ExcelUtil<Fcry>(Fcry.class);
        for (Fcry fcryExport : list) {
            if (StringUtils.isNotEmpty(fcryExport.getCommunity())) {
                List<SysDictData> communities = DictUtils.getDictCache("community");
                List<String> labels = communities.stream().filter(i -> fcryExport.getCommunity().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fcryExport.setCommunity(labels.get(0));
                } else {
                    fcryExport.setCommunity("");
                }
            } else {
                fcryExport.setCommunity("");
            }
            if (StringUtils.isNotEmpty(fcryExport.getArea())) {
                List<SysDictData> communities = DictUtils.getDictCache("residential_area");
                List<String> labels = communities.stream().filter(i -> fcryExport.getArea().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fcryExport.setArea(labels.get(0));
                } else {
                    fcryExport.setArea("");
                }
            } else {
                fcryExport.setArea("");
            }
            if (StringUtils.isNotEmpty(fcryExport.getCommittee())) {
                List<SysDictData> communities = DictUtils.getDictCache("committee");
                List<String> labels = communities.stream().filter(i -> fcryExport.getCommittee().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fcryExport.setCommittee(labels.get(0));
                } else {
                    fcryExport.setCommittee("");
                }
            } else {
                fcryExport.setCommittee("");
            }
            if (StringUtils.isNotEmpty(fcryExport.getStreet())) {
                List<SysDictData> communities = DictUtils.getDictCache("street_town");
                List<String> labels = communities.stream().filter(i -> fcryExport.getStreet().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fcryExport.setStreet(labels.get(0));
                } else {
                    fcryExport.setStreet("");
                }
            } else {
                fcryExport.setStreet("");
            }
            if (StringUtils.isNotEmpty(fcryExport.getFcPlace())) {
                List<SysDictData> communities = DictUtils.getDictCache("shelters");
                List<String> labels = communities.stream().filter(i -> fcryExport.getFcPlace().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fcryExport.setFcPlace(labels.get(0));
                } else {
                    fcryExport.setFcPlace("");
                }
            } else {
                fcryExport.setFcPlace("");
            }
        }
        util.exportExcel(response, list, "方舱人员数据");
    }

    /**
     * 获取方舱人员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fcryService.selectFcryById(id));
    }

    /**
     * 新增方舱人员
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:add')")
    @Log(title = "方舱人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Fcry fcry)
    {
        return toAjax(fcryService.insertFcry(fcry));
    }

    /**
     * 修改方舱人员
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:edit')")
    @Log(title = "方舱人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Fcry fcry)
    {
        return toAjax(fcryService.updateFcry(fcry));
    }

    /**
     * 删除方舱人员
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:remove')")
    @Log(title = "方舱人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fcryService.deleteFcryByIds(ids));
    }

    /**
     * 导出方舱人员模板
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:import')")
    @Log(title = "方舱人员", businessType = BusinessType.EXPORT)
    @PostMapping("/exportTemplate")
    public void exportTemplate(HttpServletResponse response) throws Exception {
        ExcelUtil<FcryDTO> util = new ExcelUtil<FcryDTO>(FcryDTO.class);
        Class<? extends FcryDTO>  clazz = new FcryDTO().getClass();
        //
        // 获取当前登陆人所属方舱
        String value = DataUtils.getKey(null,null,null,String.valueOf(SecurityUtils.getUserId()),null);
        List<SysDictData> fcPlace = DictUtils.getDictCache("shelters");
        List<String> labels = fcPlace.stream().filter(l->value.equals(l.getDictValue()))
                .map(SysDictData::getDictLabel).collect(Collectors.toList());
        String[] fc = labels.toArray(new String[]{});
        ExcelUtil.setClassExcelAttribute(clazz,"fcPlace","combo",fc);
//        String[] isPositive = {"阳","未阳"};
//        ExcelUtil.setClassExcelAttribute( clazz,"isPositive","combo",isPositive);
        String[] positiveOnly = {"是","否"};
        ExcelUtil.setClassExcelAttribute( clazz,"positiveOnly","combo",positiveOnly);
//        List<String> streetList = fkqkService.selectStreet();
//        String[] list = streetList.toArray(new String[]{});
//        ExcelUtil.setClassExcelAttribute( clazz,"street","combo",list);
//
//        List<String> areaList = fkqkService.selectArea();
//        String[] area = areaList.toArray(new String[]{});
//        ExcelUtil.setClassExcelAttribute( clazz,"area","combo",area);
//
//        List<String> fcList = fkqkService.selectFc();
//        String[] fc = fcList.toArray(new String[]{});
//        ExcelUtil.setClassExcelAttribute( clazz,"fcPlace","combo",fc);
        //设置文本格式表头在第几列
        String columes = "3";
        util.importTemplateExcelSetHead(response, "方舱人员导入模板",columes);
    }

    /**
     * 导入方舱人员情况
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:import')")
    @Log(title = "方舱人员", businessType = BusinessType.IMPORT)
    @PostMapping("/import")
    public void importResidential(MultipartFile file,HttpServletResponse response) throws Exception
    {
        ExcelUtil<Fcry> util = new ExcelUtil<Fcry>(Fcry.class);
        List<Fcry> residentialList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        fcryService.importUser(residentialList, operName,response);
    }
}
