package com.ruoyi.web.controller.system;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DataUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.FkqkDTO;
import com.ruoyi.system.domain.Yxry;
import com.ruoyi.system.domain.Zlqk;
import com.ruoyi.system.mapper.SysUserMapper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Fkqk;
import com.ruoyi.system.service.IFkqkService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 小区封控情况Controller
 *
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/fkqk")
public class FkqkController extends BaseController
{
    @Autowired
    private IFkqkService fkqkService;
    @Autowired
    private SysUserMapper sysUserMapper;

    /**
     * 查询小区封控情况列表
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(Fkqk fkqk)
    {
        startPage();
        List<Fkqk> list = fkqkService.selectFkqkList(fkqk);
        return getDataTable(list);
    }

    /**
     * 导出小区封控情况列表
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:export')")
    @Log(title = "小区封控情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Fkqk fkqk)
    {
        List<Fkqk> list = fkqkService.selectFkqkListExport(fkqk);
        ExcelUtil<Fkqk> util = new ExcelUtil<Fkqk>(Fkqk.class);

        for (Fkqk fkqkExport : list) {
            if (StringUtils.isNotEmpty(fkqkExport.getCommunity())) {
                List<SysDictData> communities = DictUtils.getDictCache("community");
                List<String> labels = communities.stream().filter(i -> fkqkExport.getCommunity().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fkqkExport.setCommunity(labels.get(0));
                } else {
                    fkqkExport.setCommunity("");
                }
            } else {
                fkqkExport.setCommunity("");
            }
            if (StringUtils.isNotEmpty(fkqkExport.getArea())) {
                List<SysDictData> communities = DictUtils.getDictCache("residential_area");
                List<String> labels = communities.stream().filter(i -> fkqkExport.getArea().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fkqkExport.setArea(labels.get(0));
                } else {
                    fkqkExport.setArea("");
                }
            } else {
                fkqkExport.setArea("");
            }
            if (StringUtils.isNotEmpty(fkqkExport.getStreet())) {
                List<SysDictData> communities = DictUtils.getDictCache("street_town");
                List<String> labels = communities.stream().filter(i -> fkqkExport.getStreet().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fkqkExport.setStreet(labels.get(0));
                } else {
                    fkqkExport.setStreet("");
                }
            } else {
                fkqkExport.setStreet("");
            }
            if (StringUtils.isNotEmpty(fkqkExport.getCommittee())) {
                List<SysDictData> communities = DictUtils.getDictCache("committee");
                List<String> labels = communities.stream().filter(i -> fkqkExport.getCommittee().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    fkqkExport.setCommittee(labels.get(0));
                } else {
                    fkqkExport.setCommittee("");
                }
            } else {
                fkqkExport.setCommittee("");
            }
        }
        util.exportExcel(response, list, "小区封控情况数据");
    }

    /**
     * 获取小区封控情况详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fkqkService.selectFkqkById(id));
    }

    /**
     * 新增小区封控情况
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:add')")
    @Log(title = "小区封控情况", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Fkqk fkqk)
    {
        return toAjax(fkqkService.insertFkqk(fkqk));
    }

    /**
     * 修改小区封控情况
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:edit')")
    @Log(title = "小区封控情况", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Fkqk fkqk)
    {
        return toAjax(fkqkService.updateFkqk(fkqk));
    }

    /**
     * 删除小区封控情况
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:remove')")
    @Log(title = "小区封控情况", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fkqkService.deleteFkqkByIds(ids));
    }

    /**
     * 导入小区封控情况
     */
    @Log(title = "小区封控情况", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:fkqk:import')")
    @PostMapping("/import")
    public void importResidential(MultipartFile file,HttpServletResponse response) throws Exception
    {
        ExcelUtil<Fkqk> util = new ExcelUtil<Fkqk>(Fkqk.class);
        List<Fkqk> list = util.importExcel(file.getInputStream());
        fkqkService.importUser(list, response);
    }
    /**
     * 导出小区封控情况模板
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:import')")
    @Log(title = "小区封控情况", businessType = BusinessType.EXPORT)
    @PostMapping("/exportTemplate")
    public void exportTemplate(HttpServletResponse response) throws Exception {
        ExcelUtil<FkqkDTO> util = new ExcelUtil<FkqkDTO>(FkqkDTO.class);
        Class<? extends FkqkDTO>  clazz = new FkqkDTO().getClass();
        List<String> streetList = fkqkService.selectStreet();
//        String[] list = streetList.toArray(new String[]{});
//        ExcelUtil.setClassExcelAttribute( clazz,"street","combo",list);
        String[] isJf = {"是","否"};
        ExcelUtil.setClassExcelAttribute( clazz,"isJf","combo",isJf);
        String columes = "3";
        util.importTemplateExcelSetHead(response, "小区封控情况导入模板",columes);
    }
}
