package com.ruoyi.web.controller.system;

import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DataUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.Hscj;
import com.ruoyi.system.domain.Yxry;
import com.ruoyi.system.mapper.SysDictDataMapper;
import com.ruoyi.system.mapper.SysUserMapper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Gldry;
import com.ruoyi.system.service.IGldryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 隔离点人员Controller
 *
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/gldry")
public class GldryController extends BaseController
{
    @Autowired
    private IGldryService gldryService;
    @Autowired
    private SysUserMapper sysUserMapper;
    @Autowired
    private SysDictDataMapper sysDictDataMapper;

    /**
     * 查询隔离点人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Gldry gldry)
    {
        String userType = sysUserMapper.selectUserTypeById(SecurityUtils.getUserId());
        gldry.setUserType(userType);
        if ("2".equals(userType))
            gldry.setValue(DataUtils.getKey(null, String.valueOf(SecurityUtils.getUserId()),null,null,null));
        else if ("3".equals(userType))
            gldry.setValue(DataUtils.getKey(null,null, String.valueOf(SecurityUtils.getUserId()),null,null));

        startPage();
        List<Gldry> list = gldryService.selectGldryList(gldry);
        return getDataTable(list);
    }

    /**
     * 导出隔离点人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:export')")
    @Log(title = "隔离点人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Gldry gldry)
    {
        String userType = sysUserMapper.selectUserTypeById(SecurityUtils.getUserId());
        gldry.setUserType(userType);
        if ("2".equals(userType))
            gldry.setValue(DataUtils.getKey(null, String.valueOf(SecurityUtils.getUserId()),null,null,null));
        else if ("3".equals(userType))
            gldry.setValue(DataUtils.getKey(null,null, String.valueOf(SecurityUtils.getUserId()),null,null));
        List<Gldry> list = gldryService.selectGldryListExport(gldry);
        List<SysDictData> community = DictUtils.getDictCache("community");
        List<SysDictData> committee = DictUtils.getDictCache("committee");
        List<SysDictData> street = DictUtils.getDictCache("street_town");
        for (Gldry yxry1 : list) {
            if (StringUtils.isNotEmpty(yxry1.getCommunity())) {
                List<String> labels = community.stream().filter(l -> yxry1.getCommunity().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setCommunity(labels.get(0));
            }
            if (StringUtils.isNotEmpty(yxry1.getCommittee())) {
                List<String> labels = committee.stream().filter(l -> yxry1.getCommittee().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setCommittee(labels.get(0));
            }
            if (StringUtils.isNotEmpty(yxry1.getStreet())) {
                List<String> labels = street.stream().filter(l -> yxry1.getStreet().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setStreet(labels.get(0));
            }
        }
        ExcelUtil<Gldry> util = new ExcelUtil<Gldry>(Gldry.class);
        util.exportExcel(response, list, "隔离点人员数据");
    }

    @Log(title = "导出隔离点人员导入空模板",businessType = BusinessType.EXPORT)
    @GetMapping("/importTemplate")
    public void exportTemplate(HttpServletResponse response) throws Exception {
        ExcelUtil<Gldry> util = new ExcelUtil<Gldry>(Gldry.class);
        Class<? extends Gldry> clazz = new Gldry().getClass();

        SysUser loginUser = getLoginUser().getUser();

        // 设置 隔离点名称 下拉框
//        List<SysDictData> isolation_point = sysDictDataMapper.selectDictDataByType("isolation_point");
        String glPlace = loginUser.getNickName();
        String[] glPlaces={glPlace};
        ExcelUtil.setClassExcelAttribute(clazz,"glPlace","combo",glPlaces);


        // 设置 是否阳性 下拉框
//        List<SysDictData> isYxs = DictUtils.getDictCache("is_yx");
//        String[] isYx=isYxs.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
//        ExcelUtil.setClassExcelAttribute( clazz,"isYx","combo",isYx);

//        // 设置 居住所在地 下拉框
//        List<SysDictData> dictResidentialArea = sysDictDataMapper.selectDictDataByType("residential_area");
//        String[] residentialAreas=dictResidentialArea.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
//        ExcelUtil.setClassExcelAttribute(clazz,"area","combo",residentialAreas);
//
//        // 设置 街道/镇 下拉框
//        List<SysDictData> street_town = sysDictDataMapper.selectDictDataByType("street_town");
//        String[] streetTown=street_town.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
//        ExcelUtil.setClassExcelAttribute(clazz,"street","combo",streetTown);
//
        //设置文本格式表头在第几列
        String columes = "3";
        util.importTemplateExcelSetHead(response,"隔离点人员数据导入空模板",columes);
    }

    @Log(title = "导入隔离点人员数据",businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:gldry:import')")
    @PostMapping("/importData")
    public void importGldryData(MultipartFile file, HttpServletResponse response) throws Exception{
        ExcelUtil<Gldry> util = new ExcelUtil<Gldry>(Gldry.class);
        List<Gldry> dataList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        gldryService.importList(dataList,operName,response);
    }

    /**
     * 获取隔离点人员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gldryService.selectGldryById(id));
    }

    /**
     * 新增隔离点人员
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:add')")
    @Log(title = "隔离点人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Gldry gldry)
    {
        return toAjax(gldryService.insertGldry(gldry));
    }

    /**
     * 修改隔离点人员
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:edit')")
    @Log(title = "隔离点人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Gldry gldry)
    {
        return toAjax(gldryService.updateGldry(gldry));
    }

    /**
     * 删除隔离点人员
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:remove')")
    @Log(title = "隔离点人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gldryService.deleteGldryByIds(ids));
    }

    /**
     * 根据当前登录人查询value值
     * @param type
     * @return
     */
    @GetMapping("/selectValue")
    public AjaxResult selectValue(String type) {
        String value = "";
        if ("isolation".equals(type)) //隔离点
            value = DataUtils.getKey(null,null,null,null, String.valueOf(SecurityUtils.getUserId()));
        else if ("shelters".equals(type)) //方舱
            value = DataUtils.getKey(null,null,null,String.valueOf(SecurityUtils.getUserId()),null);
        return AjaxResult.success(value);
    }
}
