package com.ruoyi.web.controller.system;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.system.domain.Gldry;
import com.ruoyi.system.domain.HsjcExportTemplate;
import com.ruoyi.system.domain.Yxry;
import com.ruoyi.system.mapper.SysDictDataMapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Hscj;
import com.ruoyi.system.service.IHscjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 核酸采集Controller
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/hscj")
public class HscjController extends BaseController
{
    @Autowired
    private IHscjService hscjService;

    @Autowired
    private SysDictDataMapper sysDictDataMapper;

    /**
     * 查询核酸采集列表
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:list')")
    @GetMapping("/list")
    public TableDataInfo list(Hscj hscj)
    {
        startPage();
        List<Hscj> list = hscjService.selectHscjList(hscj);
        return getDataTable(list);
    }

    /**
     * 导出核酸采集列表
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:export')")
    @Log(title = "核酸采集", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Hscj hscj)
    {
        List<Hscj> list = hscjService.selectHscjListExport(hscj);
        List<SysDictData> community = DictUtils.getDictCache("community");
        List<SysDictData> committee = DictUtils.getDictCache("committee");
        List<SysDictData> street = DictUtils.getDictCache("street_town");
        for (Hscj yxry1 : list) {
            if (StringUtils.isNotEmpty(yxry1.getCommunity())) {
                List<String> labels = community.stream().filter(l -> yxry1.getCommunity().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setCommunity(labels.get(0));
            }
            if (com.ruoyi.common.utils.StringUtils.isNotEmpty(yxry1.getCommittee())) {
                List<String> labels = committee.stream().filter(l -> yxry1.getCommittee().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setCommittee(labels.get(0));
            }
            if (com.ruoyi.common.utils.StringUtils.isNotEmpty(yxry1.getStreet())) {
                List<String> labels = street.stream().filter(l -> yxry1.getStreet().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setStreet(labels.get(0));
            }
        }
        ExcelUtil<Hscj> util = new ExcelUtil<Hscj>(Hscj.class);
        util.exportExcel(response, list, "核酸采集数据");
    }

    @Log(title = "导出核酸采集导入空模板",businessType = BusinessType.IMPORT)
    @GetMapping("/importTemplate")
    public void exportTemplate(HttpServletResponse response) throws Exception {
        ExcelUtil<Hscj> util = new ExcelUtil<Hscj>(Hscj.class);

        Class<? extends Hscj> clazz = new Hscj().getClass();

//        // 设置 居住所在地 下拉框
//        List<SysDictData> dictResidentialArea = sysDictDataMapper.selectDictDataByType("residential_area");
//        String[] residentialAreas=dictResidentialArea.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
//        ExcelUtil.setClassExcelAttribute(clazz,"area","combo",residentialAreas);
//
//        // 设置 街道/镇 下拉框
//        List<SysDictData> street_town = sysDictDataMapper.selectDictDataByType("street_town");
//        String[] streetTown=street_town.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
//        ExcelUtil.setClassExcelAttribute(clazz,"street","combo",streetTown);
//
//        // 设置 居委会 下拉框 （后续再写）

        // 设置 性别 下拉框
        List<SysDictData> sexList = sysDictDataMapper.selectDictDataByType("sys_user_sex");
        String[] sexs=sexList.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        ExcelUtil.setClassExcelAttribute(clazz,"sex","combo",sexs);

        // 设置 检测结果 下拉框
        String[] resList = new String[]{"阳性","阴性"};
        ExcelUtil.setClassExcelAttribute(clazz,"cjResult","combo",resList);
        //设置文本格式表头在第几列
        String columes = "7,8,11";
        util.importTemplateExcelSetHead(response,"核酸采集导入空模板",columes);
    }

    @Log(title = "导入核算采集数据",businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:hscj:import')")
    @PostMapping("/importData")
    public void importHscjData(MultipartFile file,HttpServletResponse response) throws Exception{
        ExcelUtil<Hscj> util = new ExcelUtil<Hscj>(Hscj.class);
        List<Hscj> dataList = util.importExcel(file.getInputStream());
        hscjService.importList(dataList,response);
    }

    /**
     * 获取核酸采集详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(hscjService.selectHscjById(id));
    }

    /**
     * 新增核酸采集
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:add')")
    @Log(title = "核酸采集", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Hscj hscj)
    {
        return toAjax(hscjService.insertHscj(hscj));
    }

    /**
     * 修改核酸采集
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:edit')")
    @Log(title = "核酸采集", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Hscj hscj)
    {
        return toAjax(hscjService.updateHscj(hscj));
    }

    /**
     * 删除核酸采集
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:remove')")
    @Log(title = "核酸采集", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(hscjService.deleteHscjByIds(ids));
    }

    /**
     * 校验身份证号在采集时间内是否重复
     */
    @GetMapping("/checkCard")
    public AjaxResult checkCard(Hscj hscj)
    {
        List<Hscj> list = hscjService.checkCard(hscj);
        return AjaxResult.success(list.isEmpty());
    }
}
