package com.ruoyi.web.controller.system;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.utils.DataUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.Gldry;
import com.ruoyi.system.domain.Yxry;
import com.ruoyi.system.mapper.SysUserMapper;
import com.ruoyi.system.service.ISysDictTypeService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Jcglry;
import com.ruoyi.system.service.IJcglryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 解除隔离人员Controller
 * 
 * @author ruoyi
 * @date 2022-12-01
 */
@RestController
@RequestMapping("/system/jcglry")
public class JcglryController extends BaseController
{
    @Autowired
    private IJcglryService jcglryService;
    @Autowired
    private SysUserMapper sysUserMapper;
    @Autowired
    private ISysDictTypeService dictTypeService;
    /**
     * 查询解除隔离人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:jcglry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Jcglry jcglry)
    {
        String userType = sysUserMapper.selectUserTypeById(SecurityUtils.getUserId());
        jcglry.setUserType(userType);
        if ("2".equals(userType))
            jcglry.setValue(DataUtils.getKey(null, String.valueOf(SecurityUtils.getUserId()),null,null,null));
        else if ("3".equals(userType))
            jcglry.setValue(DataUtils.getKey(null,null, String.valueOf(SecurityUtils.getUserId()),null,null));
        startPage();
        List<Jcglry> list = jcglryService.selectJcglryList(jcglry);
        return getDataTable(list);
    }

    /**
     * 导出解除隔离人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:jcglry:export')")
    @Log(title = "解除隔离人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Jcglry jcglry)
    {
        String userType = sysUserMapper.selectUserTypeById(SecurityUtils.getUserId());
        jcglry.setUserType(userType);
        if ("2".equals(userType))
            jcglry.setValue(DataUtils.getKey(null, String.valueOf(SecurityUtils.getUserId()),null,null,null));
        else if ("3".equals(userType))
            jcglry.setValue(DataUtils.getKey(null,null, String.valueOf(SecurityUtils.getUserId()),null,null));
        List<Jcglry> list = jcglryService.selectJcglryListExport(jcglry);
        List<SysDictData> shelters = DictUtils.getDictCache("shelters");
        List<SysDictData> isolationPoint = DictUtils.getDictCache("isolation_point");
        List<SysDictData> street = DictUtils.getDictCache("street_town");
        for (Jcglry yxry1 : list) {
            if (StringUtils.isNotEmpty(yxry1.getStreet())) {
                List<String> labels = street.stream().filter(l -> yxry1.getStreet().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setStreet(labels.get(0));
            }
            if (StringUtils.isNotEmpty(yxry1.getGlPlace())) {
                List<String> labels = shelters.stream().filter(l -> yxry1.getGlPlace().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setGlPlace(labels.get(0));
                else {
                    List<String> point = isolationPoint.stream().filter(l -> yxry1.getGlPlace().equals(l.getDictValue()))
                            .map(SysDictData::getDictLabel).collect(Collectors.toList());
                    if (!point.isEmpty())
                        yxry1.setGlPlace(point.get(0));
                }
            }
        }
        ExcelUtil<Jcglry> util = new ExcelUtil<Jcglry>(Jcglry.class);
        util.exportExcel(response, list, "解除隔离人员数据");
    }

    /**
     * 获取解除隔离人员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:jcglry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(jcglryService.selectJcglryById(id));
    }

    /**
     * 新增解除隔离人员
     */
    @PreAuthorize("@ss.hasPermi('system:jcglry:add')")
    @Log(title = "解除隔离人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Jcglry jcglry)
    {
        return toAjax(jcglryService.insertJcglry(jcglry));
    }

    /**
     * 修改解除隔离人员
     */
    @PreAuthorize("@ss.hasPermi('system:jcglry:edit')")
    @Log(title = "解除隔离人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Jcglry jcglry)
    {
        return toAjax(jcglryService.updateJcglry(jcglry));
    }

    /**
     * 删除解除隔离人员
     */
    @PreAuthorize("@ss.hasPermi('system:jcglry:remove')")
    @Log(title = "解除隔离人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(jcglryService.deleteJcglryByIds(ids));
    }

    /**
     * 根据字典类型查询隔离位置
     */
    @GetMapping(value = "/glPlace")
    public AjaxResult dictType()
    {
        List<SysDictData> data = new ArrayList<>();
        List<SysDictData> point = dictTypeService.selectDictDataByType("isolation_point");
        List<SysDictData> shelters = dictTypeService.selectDictDataByType("shelters");
        data.addAll(point);
        data.addAll(shelters);
        return success(data);
    }

    @PostMapping("/importTemplate")
    @PreAuthorize("@ss.hasPermi('system:jcglry:import')")
    @Log(title = "下载解除隔离人员模板", businessType = BusinessType.IMPORT)
    public void importTemplate(HttpServletResponse response) throws Exception {
        ExcelUtil<Jcglry> util = new ExcelUtil<Jcglry>(Jcglry.class);
        Class<? extends Jcglry>  clazz = new Jcglry().getClass();
        List<SysDictData> isAreas = DictUtils.getDictCache("is_area");
        List<SysDictData> glPlace = DictUtils.getDictCache("isolation_point");
        glPlace.addAll(DictUtils.getDictCache("shelters"));
        List<SysDictData> arrangeDrivers = DictUtils.getDictCache("arrange_drivers");
        String[] isArea=isAreas.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        String[] glPlaces=glPlace.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        String[] arrangeDriver=arrangeDrivers.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        String[] level={"1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19","20",
                "21","22","23","24","25","26","27","28","29","30","31","32","33","34","35","36","37","38","39","40"};
        ExcelUtil.setClassExcelAttribute( clazz,"isArea","combo",isArea);
        ExcelUtil.setClassExcelAttribute( clazz,"glPlace","combo",glPlaces);
        ExcelUtil.setClassExcelAttribute( clazz,"arrangeDrivers","combo",arrangeDriver);
        ExcelUtil.setClassExcelAttribute( clazz,"floor","combo",level);
        //设置文本格式表头在第几列
        String columes = "6";
        util.importTemplateExcelSetHead(response, "解除隔离人员",columes);
    }

    @Log(title = "导入解除隔离人员", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:jcglry:import')")
    @PostMapping("/importData")
    public void importData(MultipartFile file, HttpServletResponse response) throws Exception
    {
        ExcelUtil<Jcglry> util = new ExcelUtil<Jcglry>(Jcglry.class);
        List<Jcglry> list = util.importExcel(file.getInputStream());
        jcglryService.importList(list, response);
    }
}
