package com.ruoyi.web.controller.system;

import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.Yxry;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Wzzry;
import com.ruoyi.system.service.IWzzryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 危重症人员Controller
 * 
 * @author ruoyi
 * @date 2022-12-02
 */
@RestController
@RequestMapping("/system/wzzry")
public class WzzryController extends BaseController
{
    @Autowired
    private IWzzryService wzzryService;

    /**
     * 查询危重症人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:wzzry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Wzzry wzzry)
    {
        startPage();
        List<Wzzry> list = wzzryService.selectWzzryList(wzzry);
        return getDataTable(list);
    }

    /**
     * 导出危重症人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:wzzry:export')")
    @Log(title = "危重症人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Wzzry wzzry)
    {
        List<Wzzry> list = wzzryService.selectWzzryListExport(wzzry);
        for (Wzzry wzzry1 : list){
            if (StringUtils.isNotEmpty(wzzry1.getCommunity())) {
                List<SysDictData> communities = DictUtils.getDictCache("community");
                List<String> labels = communities.stream().filter(i -> wzzry1.getCommunity().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    wzzry1.setCommunity(labels.get(0));
                } else {
                    wzzry1.setCommunity("");
                }
            } else {
                wzzry1.setCommunity("");
            }
            if (StringUtils.isNotEmpty(wzzry1.getCommittee())) {
                List<SysDictData> communities = DictUtils.getDictCache("committee");
                List<String> labels = communities.stream().filter(i -> wzzry1.getCommittee().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    wzzry1.setCommittee(labels.get(0));
                } else {
                    wzzry1.setCommittee("");
                }
            } else {
                wzzry1.setCommittee("");
            }
            if (StringUtils.isNotEmpty(wzzry1.getStreet())) {
                List<SysDictData> communities = DictUtils.getDictCache("street_town");
                List<String> labels = communities.stream().filter(i -> wzzry1.getStreet().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    wzzry1.setStreet(labels.get(0));
                } else {
                    wzzry1.setStreet("");
                }
            } else {
                wzzry1.setStreet("");
            }
        }
        ExcelUtil<Wzzry> util = new ExcelUtil<Wzzry>(Wzzry.class);
        util.exportExcel(response, list, "危重症人员数据");
    }

    /**
     * 获取危重症人员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:wzzry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wzzryService.selectWzzryById(id));
    }

    /**
     * 新增危重症人员
     */
    @PreAuthorize("@ss.hasPermi('system:wzzry:add')")
    @Log(title = "危重症人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Wzzry wzzry)
    {
        return toAjax(wzzryService.insertWzzry(wzzry));
    }

    /**
     * 修改危重症人员
     */
    @PreAuthorize("@ss.hasPermi('system:wzzry:edit')")
    @Log(title = "危重症人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Wzzry wzzry)
    {
        return toAjax(wzzryService.updateWzzry(wzzry));
    }

    /**
     * 删除危重症人员
     */
    @PreAuthorize("@ss.hasPermi('system:wzzry:remove')")
    @Log(title = "危重症人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wzzryService.deleteWzzryByIds(ids));
    }

    @PostMapping("/importTemplate")
    @PreAuthorize("@ss.hasPermi('system:wzzry:import')")
    @Log(title = "下载危重症人员模板", businessType = BusinessType.IMPORT)
    public void importTemplate(HttpServletResponse response) throws Exception {
        ExcelUtil<Wzzry> util = new ExcelUtil<Wzzry>(Wzzry.class);
        Class<? extends Wzzry>  clazz = new Wzzry().getClass();
        List<SysDictData> userStyles = DictUtils.getDictCache("user_style");
        List<SysDictData> basicDiseases = DictUtils.getDictCache("basic_disease");
        List<SysDictData> hospitals = DictUtils.getDictCache("hospital");
        String[] userStyle=userStyles.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        String[] basicDisease=basicDiseases.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        String[] hospital=hospitals.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        String[] level={"1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19","20",
                "21","22","23","24","25","26","27","28","29","30","31","32","33","34","35","36","37","38","39","40"};
        ExcelUtil.setClassExcelAttribute( clazz,"userStyle","combo",userStyle);
        ExcelUtil.setClassExcelAttribute( clazz,"basicDisease","combo",basicDisease);
        ExcelUtil.setClassExcelAttribute( clazz,"hospital","combo",hospital);
        ExcelUtil.setClassExcelAttribute( clazz,"floor","combo",level);
        //设置文本格式表头在第几列
        String columes = "1";
        util.importTemplateExcelSetHead(response, "危重症人员",columes);
    }

    @Log(title = "导入危重症人员", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:wzzry:import')")
    @PostMapping("/importData")
    public void importData(MultipartFile file, HttpServletResponse response) throws Exception
    {
        ExcelUtil<Wzzry> util = new ExcelUtil<Wzzry>(Wzzry.class);
        List<Wzzry> list = util.importExcel(file.getInputStream());
        wzzryService.importList(list, response);
    }

}
