package com.ruoyi.web.controller.system;

import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.Fkqk;
import com.ruoyi.system.domain.Hscj;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Ycsb;
import com.ruoyi.system.service.IYcsbService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 抗原异常上报Controller
 *
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/ycsb")
public class YcsbController extends BaseController
{
    @Autowired
    private IYcsbService ycsbService;

    /**
     * 查询抗原异常上报列表
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:list')")
    @GetMapping("/list")
    public TableDataInfo list(Ycsb ycsb)
    {
        startPage();
        List<Ycsb> list = ycsbService.selectYcsbList(ycsb);
        return getDataTable(list);
    }

    /**
     * 导出抗原异常上报列表
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:export')")
    @Log(title = "抗原异常上报", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Ycsb ycsb)
    {
        List<Ycsb> list = ycsbService.selectYcsbListExport(ycsb);
        ExcelUtil<Ycsb> util = new ExcelUtil<Ycsb>(Ycsb.class);
        for (Ycsb ycsbExport : list) {
            if (StringUtils.isNotEmpty(ycsbExport.getCommunity())) {
                List<SysDictData> communities = DictUtils.getDictCache("community");
                List<String> labels = communities.stream().filter(i -> ycsbExport.getCommunity().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    ycsbExport.setCommunity(labels.get(0));
                } else {
                    ycsbExport.setCommunity("");
                }
            } else {
                ycsbExport.setCommunity("");
            }
            if (StringUtils.isNotEmpty(ycsbExport.getCommittee())) {
                List<SysDictData> committees = DictUtils.getDictCache("committee");
                List<String> labels = committees.stream().filter(i -> ycsbExport.getCommittee().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    ycsbExport.setCommittee(labels.get(0));
                } else {
                    ycsbExport.setCommittee("");
                }
            } else {
                ycsbExport.setCommittee("");
            }
            if (StringUtils.isNotEmpty(ycsbExport.getStreet())) {
                List<SysDictData> streetTown = DictUtils.getDictCache("street_town");
                List<String> labels = streetTown.stream().filter(i -> ycsbExport.getStreet().equals(i.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty()) {
                    ycsbExport.setStreet(labels.get(0));
                } else {
                    ycsbExport.setStreet("");
                }
            } else {
                ycsbExport.setStreet("");
            }
            if ("0".equals(ycsbExport.getHasAcid())) {
                ycsbExport.setHasAcid("是");
            } else if ("1".equals(ycsbExport.getHasAcid())) {
                ycsbExport.setHasAcid("否");
            }
            if ("0".equals(ycsbExport.getCheckCard())) {
                ycsbExport.setCheckCard("不正确");
            } else if ("1".equals(ycsbExport.getCheckCard())) {
                ycsbExport.setCheckCard("正确");
            }
        }
        util.exportExcel(response, list, "抗原异常上报数据");
    }

    /**
     * 获取抗原异常上报详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(ycsbService.selectYcsbById(id));
    }

    /**
     * 新增抗原异常上报
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:add')")
    @Log(title = "抗原异常上报", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Ycsb ycsb)
    {
        return toAjax(ycsbService.insertYcsb(ycsb));
    }

    /**
     * 新增抗原异常上报
     */
//    @PreAuthorize("@ss.hasPermi('system:ycsb:add')")
    @Log(title = "抗原异常上报", businessType = BusinessType.INSERT)
    @PostMapping("/addMobile")
    public AjaxResult addMobile(@RequestBody Ycsb ycsb)
    {
        ycsb.setSource("1");
        return toAjax(ycsbService.insertYcsb(ycsb));
    }

    /**
     * 修改抗原异常上报
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:edit')")
    @Log(title = "抗原异常上报", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Ycsb ycsb)
    {
        return toAjax(ycsbService.updateYcsb(ycsb));
    }

    /**
     * 删除抗原异常上报
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:remove')")
    @Log(title = "抗原异常上报", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(ycsbService.deleteYcsbByIds(ids));
    }

    /**
     * 抗原异常上报导入空模板下载
     */
    @PostMapping("/importTemplate")
    @PreAuthorize("@ss.hasPermi('system:ycsb:import')")
    @Log(title = "下载抗原异常上报模板", businessType = BusinessType.IMPORT)
    public void importTemplate(HttpServletResponse response) throws Exception {
        ExcelUtil<Ycsb> util = new ExcelUtil<>(Ycsb.class);
        Class<? extends Ycsb>  clazz = new Ycsb().getClass();
        // 是否做核酸
        String[] hasAcid = new String[]{"是", "否"};
        ExcelUtil.setClassExcelAttribute( clazz,"hasAcid","combo",hasAcid);
        //设置文本格式表头在第几列
        String columes = "4";
        util.importTemplateExcelSetHead(response,"抗原异常上报",columes);
    }

    /**
     * 导入接口
     * @param file 导入的excel文件
     * @param response
     * @throws Exception
     */
    @Log(title = "导入抗原异常上报", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:ycsb:import')")
    @PostMapping("/importData")
    public void importData(MultipartFile file, HttpServletResponse response) throws Exception {
        ExcelUtil<Ycsb> util = new ExcelUtil<>(Ycsb.class);
        List<Ycsb> list = util.importExcel(file.getInputStream());
        ycsbService.importList(list, response);
    }

    /**
     * 校验身份证号是否重复
     */
    @GetMapping("/checkCard")
    public AjaxResult checkCard(Ycsb ycsb)
    {
        List<Ycsb> list = ycsbService.checkCard(ycsb);
        return AjaxResult.success(list.isEmpty());
    }
}
