package com.ruoyi.web.controller.system;

import java.lang.reflect.Field;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Proxy;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Yxry;
import com.ruoyi.system.service.IYxryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 阳性人员Controller
 *
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/yxry")
public class YxryController extends BaseController
{
    @Autowired
    private IYxryService yxryService;


    /**
     * 获取首页数据
     */
    @GetMapping(value = "/statistics")
    public AjaxResult statistics(Yxry yxry)
    {
        return success(yxryService.statistics(yxry));
    }

    /**
     * 查询阳性人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Yxry yxry)
    {
        startPage();
        List<Yxry> list = yxryService.selectYxryList(yxry);
        return getDataTable(list);
    }

    /**
     * 导出阳性人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:export')")
    @Log(title = "阳性人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Yxry yxry)
    {
        List<Yxry> list = yxryService.selectYxryListExport(yxry);
        List<SysDictData> community = DictUtils.getDictCache("community");
        List<SysDictData> committee = DictUtils.getDictCache("committee");
        List<SysDictData> street = DictUtils.getDictCache("street_town");
        for (Yxry yxry1 : list) {
            if (StringUtils.isNotEmpty(yxry1.getCommunity())) {
                List<String> labels = community.stream().filter(l -> yxry1.getCommunity().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setCommunity(labels.get(0));
            }
            if (StringUtils.isNotEmpty(yxry1.getCommittee())) {
                List<String> labels = committee.stream().filter(l -> yxry1.getCommittee().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setCommittee(labels.get(0));
            }
            if (StringUtils.isNotEmpty(yxry1.getStreet())) {
                List<String> labels = street.stream().filter(l -> yxry1.getStreet().equals(l.getDictValue()))
                        .map(SysDictData::getDictLabel).collect(Collectors.toList());
                if (!labels.isEmpty())
                    yxry1.setStreet(labels.get(0));
            }
        }
        ExcelUtil<Yxry> util = new ExcelUtil<Yxry>(Yxry.class);
        util.exportExcel(response, list, "阳性人员数据");
    }

    /**
     * 获取阳性人员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(yxryService.selectYxryById(id));
    }

    /**
     * 新增阳性人员
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:add')")
    @Log(title = "阳性人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Yxry yxry)
    {
        return toAjax(yxryService.insertYxry(yxry));
    }

    /**
     * 修改阳性人员
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:edit')")
    @Log(title = "阳性人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Yxry yxry)
    {
        return toAjax(yxryService.updateYxry(yxry));
    }

    /**
     * 删除阳性人员
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:remove')")
    @Log(title = "阳性人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(yxryService.deleteYxryByIds(ids));
    }

    @PostMapping("/importTemplate")
    @PreAuthorize("@ss.hasPermi('system:yxry:import')")
    @Log(title = "下载阳性人员模板", businessType = BusinessType.IMPORT)
    public void importTemplate(HttpServletResponse response) throws Exception {
        ExcelUtil<Yxry> util = new ExcelUtil<Yxry>(Yxry.class);
        Class<? extends Yxry>  clazz = new Yxry().getClass();
        List<SysDictData> isYins = DictUtils.getDictCache("yin_status");
        List<SysDictData> isHomes = DictUtils.getDictCache("home_status");
        String[] isYin=isYins.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        String[] isHome=isHomes.stream().map(SysDictData::getDictLabel).toArray(String[]::new);
        String[] level={"1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19","20",
                "21","22","23","24","25","26","27","28","29","30","31","32","33","34","35","36","37","38","39","40"};
        ExcelUtil.setClassExcelAttribute( clazz,"isYin","combo",isYin);
        ExcelUtil.setClassExcelAttribute( clazz,"isHome","combo",isHome);
        ExcelUtil.setClassExcelAttribute( clazz,"floor","combo",level);
        //设置文本格式表头在第几列
        String columes = "13";
        util.importTemplateExcelSetHead(response, "阳性人员",columes);
    }

    @Log(title = "导入阳性人员", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:yxry:import')")
    @PostMapping("/importData")
    public void importData(MultipartFile file, HttpServletResponse response) throws Exception
    {
        ExcelUtil<Yxry> util = new ExcelUtil<Yxry>(Yxry.class);
        List<Yxry> list = util.importExcel(file.getInputStream());
        yxryService.importList(list, response);
    }


    /**
     * 根据身份证号查询用户隔离状态
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:query')")
    @GetMapping(value = "/selectByCard")
    public AjaxResult selectByCard(@RequestParam("card") String card)
    {
        return success(yxryService.selectByCard(card));
    }
}

